*Last update: 2018/09/03*

Scope
-------------

GrainSizeTools (GST) script is primarily targeted at anyone who wants to:

1. Visualize the distribution of apparent grain sizes and extract different statistical parameters to describe the features of the distribution and estimate the average apparent grain size
3. Estimate differential stress via paleopizometers
3. Approximate the actual 3D distribution of grain sizes from thin sections via stereology methods. This includes an estimate of the volume occupied by a particular grain size fraction using the Saltykov method and the shape of the population of grain sizes (assuming that the distribution of grain sizes is lognormal)

GST script only requires as the input the areas of the grain profiles measured grain-by-grain in a thin section. The script is not intended to determine the mean grain size via the planimetric (Jeffries) (i.e. the number of grains per unit area) or intercept (the number of grains intercepted by a test line per unit length of test line) methods. The reasons for using grain-by-grain methods over the planimetric or intercept ones in natural rocks are detailed in [Lopez-Sanchez and Llana-Fúnez (2015)](http://www.solid-earth.net/6/475/2015/). Below is a brief outline of the key assumptions to consider so that the results obtained by the script are meaningful and reliable.

### Safety concerns

> 👉 All this safety concerns assume that the calibration of the microscope and the scale of the micrographs were set correctly.

#### Determination of apparent grain sizes using different measures of central tendency (mean, median, peak/mode) 

Unidimensional apparent grain size measures such as the **arithmetic mean** or the **median** are only meaningful in specimens that show **unimodal distributions**. It is therefore key to **always visualize if the distribution shows a single peak (unimodal)**. If you observe two or more frequency peaks (multimodal distributions), you can use for comparative purposes the **location of the frequency peaks** based on the kernel density estimate (KDE) as proposed in [Lopez-Sanchez and Llana-Fúnez (2015)](http://www.solid-earth.net/6/475/2015/). Despite this, the best option in this cases is always to separate the different populations of grains using image analysis methods.

Unfortunately, no general protocol exists in the earth science community on which measure of central tendency (a.k.a "average") grain size measure to use when using grain-by-grain methods. For example, in the case of paleopiezometry studies, some authors have been using the arithmetic mean or the median, and some the mode or other types of means such as the root mean square (RMS) or the area-weighted mean. In addition, some authors applied stereological corrections and others do not, and some used logarithmic or the square root grain size scales instead of the linear one. Since it seems that this is not going to change in the short term, we propose to always report the arithmetic mean, the median, and the frequency peak. This will allow other scientists to directly compare their data with yours without using correction factors which always involve some assumptions. In any event, since you will have to choose one "average" measure in your study we advise from here to follow this rule of thumb:

- use **arithmetic mean and standard deviation (SD)** when your **distribution is normal-like or moderate-tailed**. In such cases, the position of the mean, median and frequency peak should be fairly similar. This is expected to occur when using logarithmic or square-root scales.
- use **median and interquartile (or interprecentil) range** when your **distribution is skewed (non-normal)**. In such cases the position of the mean, median and frequency peak should be well differentiated. This is expected to occur when using linear scales. A very convenient alternative for lognormal distributions is to use the **geometric mean**.
- use the **location of the frequency peak (KDE peak grain size)** when grain size in different specimens was measured with very different conditions (e.g. different resolutions, cut-offs...) (see [Lopez-Sanchez and Llana-Fúnez, 2015](http://www.solid-earth.net/6/475/2015/) for details), or when the distribution show complex or multimodal patterns (in that case only for comparative purposes).

The rationale behind this rule of thumb is that the sample means (arithmetic, geometric, etc.) are generally more efficient than the median, meaning that it performs better under ideal circumstances. In contrast, the median is more robust, meaning that it performs pretty well under less than ideal circumstances. This feature makes the median more efficient when distributions have "thick" tails as it happens in most skewed distributions and the sample size "small" since medians ignore extreme values. Both, the mean and the median, are in turn more efficient "average" measures than the frequency peak but if you want to compare grain sizes in specimens that were measured at very different conditions (e.g. different resolutions, applying different cut-offs, etc.), then **you should use the location of the frequency peak (peak grain size)** instead. This is because the frequency peak is the only central tendency measure not affected by these factors and thus the only robust estimate in such situations (Fig. 1) ([Lopez-Sanchez and Llana-Fúnez, 2015](http://www.solid-earth.net/6/475/2015/)). In the end, choose between the different "average" measures is about finding a trade-off between efficiency and robustness since both concepts are usually in tension.

> 👉 In the case of multiplicative relationships such as lognormal or exponential distributions, the **geometric mean** has some advantages over the **arithmetic mean**. The geometric mean multiplies rather than sums the values and then takes the *nth* root. This operation is similar to compute the logarithm of all values, then calculating the mean and finally taking the antilog. This means that in a perfect lognormal distribution the geometric mean will provide a better central tendency value compare to the arithmetic mean. Indeed in perfect lognormal distribution, the geometric mean and the median will have similar values. The geometric mean is theoretically more efficient than the median, however, the median is clearly a better option when you suspect that some data in your dataset is contaminated since it is more robust (e.g. Shih and Binkowitz, 1987) 

![Figure 1 Scope](https://github.com/marcoalopez/GrainSizeTools/blob/master/FIGURES/Diff_cutoffs.png?raw=true)

*Figure 1. Two different grain size distributions from the same EBSD dataset due to applying different cleaning protocols during grain reconstruction. **Only the KDE frequency peak remains the same**. Specifically, grains with less than 4 (left) and 10 (right) pixels were removed, both common cut-offs during EBSD grain reconstruction routines. The high cut-off imposed on the population in the right creates an artificial asymmetry in the distribution of logarithmic grain sizes shifting the mean and the median to higher values.*

When grains are equant (equiaxed) or near-equant (i.e. aspect ratios mostly < 2.0) any specimen orientation is acceptable for estimating the grain size. In such case, a **single section** is enough to obtain a reliable estimate as long as you measure a minimum of grain sections (see below for details). When the aspect ratio of grains are commonly above 2.0  and there is preferred orientation throughout the rock volume, you will need to **estimate the grain size over three orthogonal sections and then average the results to obtain meaningful results** (for every independent grain size measure). Although specimens with equant grains accept any orientation to estimate unidimensional grain size measures, it is advisable to use a principal section. Specifically, we promote the use of the XZ section, i.e. parallel to the lineation and perpendicular to the foliation, since this will allow us: (i) to estimate whether the grains are far from equant using the aspect ratio; and (ii) to provide a fairer comparison between different specimens when near-equant grains and preferred orientation of the large axes exist.

To obtain reliable grain size estimates you should measure or your grain boundary map should contain at least 433 grain sections. This sample size will ensure that 95 % of the time the mean grain size estimated will have an error equal or less than ± 4 %; if you use 965 sections, a practice that we recommend here, this will ensure the 99% of the time instead ([Lopez-Sanchez and Llana-Fúnez, 2015](http://www.solid-earth.net/6/475/2015/)). If you want to obtain an accurate **confidence interval** for your estimates, then you need to take several representative micrographs from the same specimen (three or more) and estimate the "average" (mean, median or peak) grain size in each of them. Then use the ```confidence_interval``` function implemented in the script to get a robust confidence interval. For details on how this determination works see the next section or the documentation of the function using the command ``help(confidence_interval)`` in the console.

Regarding paleopizometry estimates, **avoid using stereological methods or correction factors** in the estimates but directly report apparent grain size measurements. The rationale behind this is that **stereological methods/factors are built on several (ill-conditioned) geometric assumptions and the results will always be, at best, only approximate**. This means that the precision of the estimated 3D size distribution is **much poorer** than the precision of the original distribution of grain profiles since the latter is based on real data not a model.

#### Determination of stress via paleopiezometers

When using a piezometer relation is of paramount importance to ensure what type of grain size measure should be used. For example, if you want to use the piezometric relation for quartz established in Stipp and Tullis (2003), note that they used the **root mean square apparent diameter** not the *linear nor the logarithmic mean diameter*. Also, it is important to note that the mean of the logarithmic or square-root apparent grain size is not the same as calculating the logarithm or the square root of the mean apparent grain size using a linear scale. For more details see the step-by-step tutorial.

It is always advisable to calculate a **confidence interval** for your paleopiezometry estimates, which means that you should do at least three independent measures (i.e. from different grain size maps). Since version 1.4.4+, the GST script implements a function to **estimate robust confidence intervals using the student's t-distribution** (see the step-by-step tutorial for details). This is a much robust approach than calculating the mean plus two times the standard deviation when the mean and the SD cannot be estimated accurately because the sample size is small (< 10).

#### Getting the shape of actual grain size distribution or the volume occupied by a particular grain size fraction

Estimating the actual grain size distribution from thin sections using stereological methods requires assuming spatial homogeneity and that **grains under study are equant or near-equant**. The Saltykov and two-step methods will not provide reliable results if most of the grains show aspect ratios above 2.0, regardless of whether a shape preference orientation exists or not. In any event, this assumption is acceptable most of the time for the most common recrystallized (dynamically or statically) mineral phases in crustal and mantle shear zones, which includes quartz, feldspar, olivine, and calcite, as well as ice. However, be careful when recrystallized grains show very irregular/lobate grain boundaries (i.e. low "solidity" values).

The Saltykov method is suitable to estimate approximately the volume of a particular grain fraction of interest (in percentage) and to visualize the aspect of the derived 3D grain size distribution using the histogram and a volume-weighted cumulative frequency curve. To provide reliable results, the method requires using a few numbers of classes and a large number of individual grain measurements. Practical experience indicates using more than 1000 grain sections and less than 20 classes. Unfortunately, the optimal number of classes depends on the type of distribution and the range of values; and the latter can vary largely due to presence or absence of grains with very large sizes. In conclusion, the number of classes has to be set by a trial and error approach. This will inevitably lead to different authors using a different number of classes across studies. Due to this, when estimating the volume of a grain size fraction based on a single grain boundary map it is necessary to take an absolute error of ± 5 to stay safe (see details in [Lopez-Sanchez and Llana-Fúnez, 2016](http://www.sciencedirect.com/science/article/pii/S0191814116301778)). If possible, take more than one representative grain boundary map and then estimate a confidence interval as explained above in this section.

The two-step method ([Lopez-Sanchez and Llana-Fúnez, 2016](http://www.sciencedirect.com/science/article/pii/S0191814116301778)) is suitable for describing quantitatively the shape of the actual 3D grain size distribution using a single parameter called the multiplicative standard deviation (MSD) value. The method assumes that the actual grain size distribution follows a lognormal distribution and thus **it is critical to visualize first an estimate of the actual distribution of grain sizes using the Saltykov method and ensure that the distribution is unimodal and lognormal-like**. The MSD estimate is independent of the chosen number of classes as long as the Saltykov method produces stable results.


[next section](https://github.com/marcoalopez/GrainSizeTools/blob/master/DOCS/brief_tutorial.md)  
[table of contents](https://github.com/marcoalopez/GrainSizeTools/blob/master/DOCS/tableOfContents.md)
